==> edna2-0.1.4-.tar.gz: edna2-0.1.4-/beetsplug/static/js/edna2.js <==
$(function() {
    /*********************************************
     * SOME RESOURCES
    *********************************************/

    /*********************************************
      DECLARE PREFERENCE VARIABLES
    *********************************************/
    var autoloop = false;

    /*********************************************
      DECLARE GLOBALS FOR AUDIOJS
    *********************************************/
    var a = audiojs.createAll({
        trackEnded: move_to_next
    })

    var audio = a[0]

    /*********************************************
      START OF PRELOADING
    *********************************************/
    var tracks = new Array();
    var albums = new Array();
    var artists = new Array();

    function load_everything() {
        tracks_loaded = false;
        albums_loaded = false;
        artists_loaded = false;

        tracks_dump = $("#tracks .entry")
        tracks_dump_unprocessed = tracks_dump.length;

        tracks_dump.each(function() {
            dataid = $(this).attr("dataid")
            $.getJSON("/item/" + dataid, function(data) {
                tracks[data.id-1] = data;
                //tracks.push(jQuery.extend(true, {}, data))
                tracks_dump_unprocessed -= 1;
                if (tracks_dump_unprocessed === 0) {
                    /*
                    tracks = tracks.sort(function(a, b) {
                        //So apparently ids are strings by default?
                        return parseInt(a.id) - parseInt(b.id)
                    })
                    */

                    tracks_loaded = true;
                    if (tracks_loaded && albums_loaded && artists_loaded) {
                        show_content();
                    }
                }
            });
        })

        album_dump = $("#albums .entry");
        albums_dump_unprocessed = album_dump.length;

        album_dump.each(function() {
            dataid = $(this).attr("dataid")
            $.getJSON("/album/" + dataid, function(data) {
                albums.push(data);
                albums_dump_unprocessed -= 1;
                if (albums_dump_unprocessed === 0) {
                    albums = albums.sort(function(a, b) {
                        return a[0] - b[0];
                    })

                    albums_loaded = true;
                    if (tracks_loaded && albums_loaded && artists_loaded) {
                        show_content();
                    }
                }
            });
        });

        artist_dump = $("#artists .entry");
        artist_dump_unprocessed = artist_dump.length;

        $("#artists .entry").each(function() {
            id = $(this).attr("dataid")
            album_list = $(this).attr("album-list")
            artists[id] = JSON.parse(album_list)

            artist_dump_unprocessed -= 1;
            if (artist_dump_unprocessed === 0) {

                //artists = artists.sort(function(a, b) {
                //    return a[0] - b[0];
                //});

                artists_loaded = true;
                if (tracks_loaded && albums_loaded && artists_loaded) {
                    show_content();
                }
            }
        });
    }

    load_everything();
    
    function show_content() {
        $("#content").show();
        $("#content-loading").hide();
    }

    /*********************************************
      END OF PRELOADING
    *********************************************/

    //Drag and drop re-sorting
    $("#playlist").dragsort({
        dragSelector: "li",
        dragEnd: function() {},
        dragBetween: false,
        placeHolderTemplate: "<li></li>"
    });

    //Bind click handlers to their respective stuffs
    $("#clear_playlist").bind("click", clear_playlist)
    $("#shuffle_playlist").bind("click", shuffle_playlist)
    $("#autoloop_status").bind("click", toggle_autoloop)
    $("#query").focus()


    /*********************************************
      AUTOLOOP GRAPHICAL STUFFS
    *********************************************/
    autoloop_on = $("<img src = 'static/img/loop_active.png'>")
    autoloop_off = $("<img src = 'static/img/loop_inactive.png'>")
    $("#autoloop_status").append(autoloop_off)


    //This is the query handler
    $("#query").bind('input', function() {
        $("#navigation a:first").tab('show');
        text = $("#query").val()
        $(".clickable").not(":contains('" + text + "')").hide()
        $(".clickable:contains('" + text + "')").show()
    });

    /*********************************************
      START OF INSTA-SEARCH FUNCTIONS
    *********************************************/
    jQuery.expr[':'].Contains = function(a, i, m) {
      return jQuery(a).text().toUpperCase()
      .indexOf(m[3].toUpperCase()) >= 0;
    };

    jQuery.expr[':'].contains = function(a, i, m) {
      return jQuery(a).text().toUpperCase()
          .indexOf(m[3].toUpperCase()) >= 0;
    }  
    /*********************************************
      END OF INSTA-SEARCH FUNCTIONS
    *********************************************/

    //Utility for getting the time in seconds into
    //minutes and seconds
    function proper_time(seconds) {
        seconds = parseInt(seconds);
        minutes = parseInt(seconds / 60);
        seconds = parseInt(seconds - minutes * 60);

        if (seconds < 10) {
            seconds = "0" + seconds;
        }
        return minutes + ":" + seconds
    }
    
    //Actually download the song
    function get_audio_src(dataid) {
        audio_src = "/item/" + dataid + "/file"
        return audio_src;
    }
    
    //Start playing a song with a given dataid
    function start_playing(dataid) {
        display_info(dataid)
        audio.load(get_audio_src(dataid));
        audio.play()
    }
    
    //Stop playing all curently playing songs
    function stop_playing() {
        $("#playlist li.playing").removeClass("playing")
        audio.pause()
    }

    /*********************************************
      START OF PLAYLIST INTERACTION
    *********************************************/

    //Add a song to a playlist
    function add_to_playlist(dataid, text) {

        playlist = $("#playlist");
        playlist_entry = $("<li></li>")
        song = $("<a dataid = '" + dataid + "' + href = ''>" + text + "</a>");
        removebtn = $("<img src = 'static/img/remove.png'>");

        song.bind("click", playlist_handler)
        removebtn.bind("click", remove_handler)
        playlist_entry.append(removebtn)
        playlist_entry.append(song)
        
        playlist.append(playlist_entry)

        if (!$('#playlist li.playing').length) {
            song.click()
        }
    }

    //Allows a song to be removed from the playlist
    function remove_handler(e) {
        target = $(e.target)

        //Case 1, this is the only element and it's playing
        if (target.closest("ol").children().length == 1)
            stop_playing()

        //Case 2, this element is currently playing 
        else if (target.closest("li").hasClass("playing"))
            move_to_next()

        target.closest("li").remove()
    }

    //Shuffle the playlist
    function shuffle_playlist() {
        var obj = $("#playlist li")
        var arr = $.makeArray(obj)
        
        for (var i = 0; i < arr.length; i++) {
            j = Math.floor(Math.random()*arr.length)
            swap = arr[i];
            arr[i] = arr[j];
            arr[j] = swap;
        }

        $("#playlist").html($(arr))
    }

    //Clear the playlist
    function clear_playlist() {
        stop_playing();
        $("#playlist").html("")
    }
    
    //Turn autoloop on and off
    function toggle_autoloop(e) {
        autoloop = !autoloop

        if (autoloop)
            $("#autoloop_status").html(autoloop_on)
        else
            $("#autoloop_status").html(autoloop_off)
    }

    /*********************************************
      END OF PLAYLIST INTERACTION
    *********************************************/

    //Display information about a song given it's dataid
    function display_info(dataid) {
        //tracks array starts at 0, dataids start at 1
        data = tracks[dataid-1]
        album_src = "/album/" + data.album_id + "/art"
        $("#album-artist").html(data.artist_sort)
        $("#album-title").html(data.album)
        $("#track-title").html(data.title)
        $("#track-number").html(data.track)
        $("#track-total").html(data.tracktotal)
        $("#track-format").html(data.format)
        $("#track-length").html(proper_time(data.length));
        $("#track-bitrate").html(parseInt(data.bitrate) / 1000 + " kbps");
        $("#track-mb").html("<a href = 'http://musicbrainz.org/recording/" + data.mb_trackid + "'>MusicBrainz Link</a>")
        $("#album-art").html('<img src = "' + album_src + '" style = "max-width: 300px; max-height: 300px;"/>')
    }

    //Move to the next audio track
    function move_to_next() {
        var next = $('#playlist li.playing').next();

        if (!next.length) {
            if (autoloop)
                next = $('#playlist li').first();
            else
                next = false;
        }

        if (next.length) {
            next.addClass('playing').siblings().removeClass('playing');

            dataid = $('a', next).attr('dataid')
            start_playing(dataid)
        }
        else
            stop_playing()

    }

    function queue_song(dataid, title) {
        add_to_playlist(dataid, tracks[dataid-1].title);
    }

    function queue_album(dataid) {
        album = albums[dataid-1];
        album_tracks = new Array()
        for (var i = 0; i < album.length; i++) {
            track = tracks[album[i]-1]
            album_tracks.push(track)
        }

        //sort these according to track before playing
        album_tracks = album_tracks.sort(function(a, b) {
            return parseInt(a.track) - parseInt(b.track)
        })

        for (var i = 0; i < album.length; i++) {
            queue_song(album_tracks[i].id, album_tracks[i].title)
        }
    }

    function click_handler(e) {
        e.preventDefault();
        target = $(e.target)
        dataid = target.attr("dataid")

        if (target.attr('type') === 'track') {
            queue_song(dataid, tracks[dataid-1].title)
        }

        else if (target.attr('type') === 'album') {
            queue_album(dataid)
        }

        else {  
            queue_album_list = artists[dataid]
            for (var i = 0; i < queue_album_list.length; i++) {
                queue_album(queue_album_list[i]);
            }
        }
             
    }

    function playlist_handler(e) {
        e.preventDefault()
        target = $(e.target);
        target.parent().addClass("playing");
        target.parent().siblings().removeClass("playing");

        dataid = target.attr("dataid");
        start_playing(dataid)
    }


    $(".searchable").delegate(".clickable", "click", click_handler);

    $("#brand").click(function(e) {
        e.preventDefault();
        $("#navigation a:first").tab('show');
    })

});

==> edna2-0.2.0.tar.gz: edna2-0.2.0/beetsplug/static/js/edna2.js <==
$(function() {
    /*********************************************
     * SOME RESOURCES
    *********************************************/

    /*********************************************
      DECLARE PREFERENCE VARIABLES
    *********************************************/
    var autoloop = false;

    /*********************************************
      DECLARE GLOBALS FOR AUDIOJS
    *********************************************/
    var a = audiojs.createAll({
        trackEnded: move_to_next
    })

    var audio = a[0]

    /*********************************************
      START OF PRELOADING
    *********************************************/
    var tracks = new Array();
    var albums = new Array();
    var artists = new Array();

    function load_everything() {
        tracks_loaded = false;
        albums_loaded = false;
        artists_loaded = false;

        tracks_dump = $("#tracks .entry")
        tracks_dump_unprocessed = tracks_dump.length;

        tracks_dump.each(function() {
            dataid = $(this).attr("dataid")
            $.getJSON("/item/" + dataid, function(data) {
                tracks[data.id-1] = data;
                //tracks.push(jQuery.extend(true, {}, data))
                tracks_dump_unprocessed -= 1;
                if (tracks_dump_unprocessed === 0) {
                    /*
                    tracks = tracks.sort(function(a, b) {
                        //So apparently ids are strings by default?
                        return parseInt(a.id) - parseInt(b.id)
                    })
                    */

                    tracks_loaded = true;
                    if (tracks_loaded && albums_loaded && artists_loaded) {
                        show_content();
                    }
                }
            });
        })

        album_dump = $("#albums .entry");
        albums_dump_unprocessed = album_dump.length;

        album_dump.each(function() {
            dataid = $(this).attr("dataid")
            $.getJSON("/album/" + dataid, function(data) {
                albums.push(data);
                albums_dump_unprocessed -= 1;
                if (albums_dump_unprocessed === 0) {
                    albums = albums.sort(function(a, b) {
                        return a[0] - b[0];
                    })

                    albums_loaded = true;
                    if (tracks_loaded && albums_loaded && artists_loaded) {
                        show_content();
                    }
                }
            });
        });

        artist_dump = $("#artists .entry");
        artist_dump_unprocessed = artist_dump.length;

        $("#artists .entry").each(function() {
            id = $(this).attr("dataid")
            album_list = $(this).attr("album-list")
            artists[id] = JSON.parse(album_list)

            artist_dump_unprocessed -= 1;
            if (artist_dump_unprocessed === 0) {

                //artists = artists.sort(function(a, b) {
                //    return a[0] - b[0];
                //});

                artists_loaded = true;
                if (tracks_loaded && albums_loaded && artists_loaded) {
                    show_content();
                }
            }
        });
    }

    load_everything();
    
    function show_content() {
        $("#content").show();
        $("#content-loading").hide();
    }

    /*********************************************
      END OF PRELOADING
    *********************************************/

    //Drag and drop re-sorting
    $("#playlist").dragsort({
        dragSelector: "li",
        dragEnd: function() {},
        dragBetween: false,
        placeHolderTemplate: "<li></li>"
    });

    //Bind click handlers to their respective stuffs
    $("#clear_playlist").bind("click", clear_playlist)
    $("#shuffle_playlist").bind("click", shuffle_playlist)
    $("#autoloop_status").bind("click", toggle_autoloop)
    $("#query").focus()


    /*********************************************
      AUTOLOOP GRAPHICAL STUFFS
    *********************************************/
    //autoloop_on = $("<img src = 'static/img/loop_active.png'>")
    //autoloop_off = $("<img src = 'static/img/loop_inactive.png'>")
    autoloop_on = $("<div class = 'btn btn-primary'>Loop On</div>");
    autoloop_off = $("<div class = 'btn'>Loop Off</div>");
    $("#autoloop_status").append(autoloop_off)


    //This is the query handler
    $("#query").bind('keyup', function() {
        $("#navigation a:first").tab('show');
        text = $("#query").val()
        $(".clickable").not(":contains('" + text + "')").hide()
        $(".clickable:contains('" + text + "')").show()
    });

    /*********************************************
      START OF INSTA-SEARCH FUNCTIONS
    *********************************************/
    jQuery.expr[':'].Contains = function(a, i, m) {
      return jQuery(a).text().toUpperCase()
      .indexOf(m[3].toUpperCase()) >= 0;
    };

    jQuery.expr[':'].contains = function(a, i, m) {
      return jQuery(a).text().toUpperCase()
          .indexOf(m[3].toUpperCase()) >= 0;
    }  
    /*********************************************
      END OF INSTA-SEARCH FUNCTIONS
    *********************************************/

    //Utility for getting the time in seconds into
    //minutes and seconds
    function proper_time(seconds) {
        seconds = parseInt(seconds);
        minutes = parseInt(seconds / 60);
        seconds = parseInt(seconds - minutes * 60);

        if (seconds < 10) {
            seconds = "0" + seconds;
        }
        return minutes + ":" + seconds
    }
    
    //Actually download the song
    function get_audio_src(dataid) {
        audio_src = "/item/" + dataid + "/file"
        return audio_src;
    }
    
    //Start playing a song with a given dataid
    function start_playing(dataid) {
        $("#now-playing").show();
        display_info(dataid)
        audio.load(get_audio_src(dataid));
        audio.play()
    }
    
    //Stop playing all curently playing songs
    function stop_playing() {
        $("#now-playing").hide();
        $("#playlist li.playing").removeClass("playing")
        audio.pause()
    }

    /*********************************************
      START OF PLAYLIST INTERACTION
    *********************************************/

    //Add a song to a playlist
    function add_to_playlist(dataid, text, playNow) {

        playlist = $("#playlist");
        playlist_entry = $("<li></li>")
        song = $("<a dataid = '" + dataid + "' + href = ''>" + text + "</a>");
        removebtn = $("<i class = 'icon-remove'></i>");

        song.bind("click", playlist_handler)
        removebtn.bind("click", remove_handler)
        playlist_entry.append(removebtn)
        playlist_entry.append(song)
        
        playlist.append(playlist_entry)

        if (playNow) {
            song.click()
        }
    }

    //Allows a song to be removed from the playlist
    function remove_handler(e) {
        target = $(e.target)

        //Case 1, this is the only element and it's playing
        if (target.closest("ol").children().length == 1)
            stop_playing()

        //Case 2, this element is currently playing 
        else if (target.closest("li").hasClass("playing"))
            move_to_next()

        target.closest("li").remove()
    }

    //Shuffle the playlist
    function shuffle_playlist() {
        var obj = $("#playlist li")
        var arr = $.makeArray(obj)
        
        for (var i = 0; i < arr.length; i++) {
            j = Math.floor(Math.random()*arr.length)
            swap = arr[i];
            arr[i] = arr[j];
            arr[j] = swap;
        }

        $("#playlist").html($(arr))
    }

    //Clear the playlist
    function clear_playlist() {
        stop_playing();
        $("#playlist").html("")
    }
    
    //Turn autoloop on and off
    function toggle_autoloop(e) {
        autoloop = !autoloop

        if (autoloop)
            $("#autoloop_status").html(autoloop_on)
        else
            $("#autoloop_status").html(autoloop_off)
    }

    /*********************************************
      END OF PLAYLIST INTERACTION
    *********************************************/

    //Display information about a song given it's dataid
    function display_info(dataid) {
        //tracks array starts at 0, dataids start at 1
        data = tracks[dataid-1]
        album_src = "/album/" + data.album_id + "/art"
        $("#album-artist").html(data.artist_sort)
        $("#album-title").html(data.album)
        $("#track-title").html(data.title)
        $("#track-number").html(data.track)
        $("#track-total").html(data.tracktotal)
        $("#track-format").html(data.format)
        $("#track-length").html(proper_time(data.length));
        $("#track-mb").html("<a href = 'http://musicbrainz.org/recording/" + data.mb_trackid + "'>MusicBrainz Link</a>")
        $("#album-art").html('<img src = "' + album_src + '" style = "max-width: 300px; max-height: 300px;"/>')
    }

    //Move to the next audio track
    function move_to_next() {
        var next = $('#playlist li.playing').next();

        if (!next.length) {
            if (autoloop)
                next = $('#playlist li').first();
            else
                next = false;
        }

        if (next.length) {
            next.addClass('playing').siblings().removeClass('playing');

            dataid = $('a', next).attr('dataid')
            start_playing(dataid)
        }
        else
            stop_playing()

    }

    function queue_song(dataid, title, playNow) {
        add_to_playlist(dataid, tracks[dataid-1].title, playNow);
    }

    function queue_album(dataid, playNow) {
        album = albums[dataid-1];
        album_tracks = new Array()
        for (var i = 0; i < album.length; i++) {
            track = tracks[album[i]-1]
            album_tracks.push(track)
        }

        //sort these according to track before playing
        album_tracks = album_tracks.sort(function(a, b) {
            return parseInt(a.track) - parseInt(b.track)
        })

        for (var i = 0; i < album.length; i++) {
            //play the first song we add, but no more
            queue_song(album_tracks[i].id, album_tracks[i].title, playNow);
            playNow = false;
        }
    }

    function click_handler(e) {
        e.preventDefault();
        target = $(e.target)
        playNow = true 

        if (target.hasClass("icon-plus")) {
            //Grab the actual data target
            target = target.siblings(".entry")
            playNow = false;
        }

        dataid = target.attr("dataid");
        type = target.attr("type");


        //If it's icon-plus, that means don't start
        //playing it as soon as we add, otherwise
        //we do want to start playing as soon as we add
        add_based_on_type(dataid, type, playNow);
             
    }
    
    //This function is to eliminate duplication in the above
    //function when we either want to add something or just
    //start playing it immediatly
    function add_based_on_type(dataid, type, playNow) {
        if (type === 'track') {
            queue_song(dataid, tracks[dataid-1].title, playNow)
        }

        else if (type === 'album') {
            queue_album(dataid, playNow)
        }

        else {  
            queue_album_list = artists[dataid]
            for (var i = 0; i < queue_album_list.length; i++) {
                queue_album(queue_album_list[i], playNow);
            }
        }
    }

    function playlist_handler(e) {
        e.preventDefault()
        target = $(e.target);
        target.parent().addClass("playing");
        target.parent().siblings().removeClass("playing");

        dataid = target.attr("dataid");
        start_playing(dataid)
    }


    $(".searchable").delegate(".clickable", "click", click_handler);

    $("#brand").click(function(e) {
        e.preventDefault();
        $("#navigation a:first").tab('show');
    })

});
